from prettyqt.qt import QtQml


class QmlParserStatus(QtQml.QQmlParserStatus):
    pass
